@@ -121,6 +121,32 @@ class Cli:
         from .multiprocess import kill
         return kill(ports, view)
 
+    @staticmethod
+    def split(file_path: str, chunk_size=1024*1024*1024):
+        """将大文件分割成多个块。
+
+        Args:
+            file_path (str): 原始文件的路径。
+            chunk_size (int): 每个块的大小（字节）。
+
+        """
+
+        from .io.ops import split_file
+        return split_file(file_path, chunk_size=chunk_size)
+
+    @staticmethod
+    def merge(input_prefix, input_dir='./', output_path=None):
+        """将分割后的文件块拼接回一个文件。
+
+        Args:
+            input_prefix (str): 分割文件的前缀。
+            input_dir (str): 原始文件所在目录。
+            output_path (str): 拼接后的文件路径。
+
+        """
+        from .io.ops import join_files
+        return join_files(input_prefix=input_prefix, input_dir=input_dir, output_path=output_path)
+
     @staticmethod
     def clone(url: str, save_path=None, branch=None, proxy=False):
         kwargs = locals()
